@@ -26,7 +26,11 @@ class Fetcher:
     """Fetcher gets the HTML contents of CNN's Fear & Greed Index website."""
 
     def __call__(self) -> dict:
-        r = requests.get(URL)
+        headers = {
+            "User-Agent": "Mozilla",
+        }
+        r = requests.get(URL, headers=headers)
+        r.raise_for_status()
         return r.json()
 
 
